/**
 * Sample positioning bridge for accessing Legato positioning service from Java
 *
 * Copyright (C) Sierra Wireless Inc.
 */

#include <legato.h>
#include <interfaces.h>
#include <sample_PositioningBridge.h>

JNIEXPORT jlong JNICALL Java_sample_PositioningBridge_start
  (JNIEnv *jniEnv, jclass class)
{
    le_result_t result;

    result = le_pos_SetAcquisitionRate(1000);
    if (result != LE_OK)
    {
        return 0;
    }
    
    return (ssize_t)le_posCtrl_Request();
}

JNIEXPORT void JNICALL Java_sample_PositioningBridge_stop
  (JNIEnv *jniEnv, jclass class, jlong ref)
{
    le_posCtrl_Release((le_posCtrl_ActivationRef_t)((ssize_t)ref));
}

JNIEXPORT jobject JNICALL Java_sample_PositioningBridge_Get2DLocation
  (JNIEnv *jniEnv, jclass class)
{
    jclass point2DClass = (*jniEnv)->FindClass(jniEnv, "sample/PositioningBridge$Point2D");
    jmethodID point2DConstructor = (*jniEnv)->GetMethodID(jniEnv, point2DClass, "<init>", "(III)V");
    int32_t latitude, longitude, accuracy;

    le_result_t result = le_pos_Get2DLocation(&latitude, &longitude, &accuracy);

    if (result == LE_OK)
    {
        return (*jniEnv)->NewObject(jniEnv,
                                    point2DClass, point2DConstructor,
                                    latitude, longitude, accuracy);
    }
    else
    {
        return NULL;
    }
    
}

COMPONENT_INIT
{
}
